@@ -10,5 +10,7 @@ class Bash:
         self._parser.add_argument('--root', action='store')
         known, unknown = self._parser.parse_known_args(input)
         self.commands = unknown
-        directory = known.root or FilesystemRoot.default_directory()
-        self.root = FilesystemRoot(directory)
+        if known.root:
+            self.root = FilesystemRoot(known.root)
+        else:
+            self.root = FilesystemRoot()
