@@ -1,6 +1,6 @@
 from ..commander import QueueCommand
 from ..commander import Commander
-from ..ui.add_task_ui import AddTaskUi
+from ..ui.edit_task_ui import EditTaskUi
 
 
 class AddCommand(QueueCommand):
@@ -15,7 +15,7 @@ class AddCommand(QueueCommand):
 
     def execute_on_queue(self, parsed, queue):
         if parsed.interactive:  # pragma: no cover
-            frame = AddTaskUi(lambda task: queue.add(task))
+            frame = EditTaskUi(lambda task: queue.add(task))
         else:
             if hasattr(parsed, 'item') and parsed.item:
                 item = parsed.item
