@@ -1,7 +1,6 @@
 from unittest import TestCase
 from unittest import mock
 from tempfile import TemporaryDirectory
-import subprocess
 import os
 
 from busy.bash import Bash
@@ -18,7 +17,6 @@ class TestBash(TestCase):
         self.tempdir.cleanup()
 
     def test_commands(self):
-        d = FilesystemRoot.default_directory()
         b = Bash('a', 'b')
         self.assertEqual(b.commands, ['a', 'b'])
 
