@@ -34,14 +34,14 @@ class TestTask(TestCase):
             t.as_plan(54)
 
     def test_plan_with_date_as_string(self):
-        t = Task ('d')
+        t = Task('d')
         p = t.as_plan('2019-04-05')
         self.assertEqual(p.date.day, 5)
 
     def test_create_plan_with_dict(self):
-        t = Plan(date=(2019,4,15), description='a')
+        t = Plan(date=(2019, 4,15), description='a')
         self.assertEqual(t.date.month, 4)
-
+ 
     def test_tags(self):
         t = Task('f #a')
         self.assertEqual(t.tags, ['a'])
@@ -49,3 +49,19 @@ class TestTask(TestCase):
     def test_project(self):
         t = Task("k #oNe #two")
         self.assertEqual(t.project, 'one')
+
+    def test_resource(self):
+        t = Task("a at https://b.us #f")
+        self.assertEqual(t.resource, "https://b.us")
+    
+    def test_resource_without_at(self):
+        t = Task("e")
+        self.assertEqual(t.resource, "")
+
+    def test_without_resource(self):
+        t = Task("a at https://b.us #f")
+        self.assertEqual(t.without_resource, 'a #f')
+
+    def test_without_resource_without_at(self):
+        t = Task("f")
+        self.assertEqual(t.without_resource, "f")
